<?php
namespace MASCOTCOREMEDINOV\Shortcodes\NavTabsHolder;

use MASCOTCOREMEDINOV\Shortcodes\Lib;

/**
 * class SC_Nav_Tabs_Holder
 * @package MASCOTCOREMEDINOV\Shortcodes\NavTabsHolder;
 */
class SC_Nav_Tabs_Holder implements Lib\Mascot_Core_Medinov_Interface_Shortcodes {
	
	/**
	 * @var shortcode_base
	 */
	private $shortcode_base;

	/**
	 * construct
	 */
	public function __construct() {
		$this->shortcode_base = 'tm_nav_tabs_holder';
		add_action('init', array($this, 'MapShortCodeVC'), 998);
	}

	/**
	 * Returns shortcode_base for shortcode
	 */
	public function getShortCodeBase() {
		return $this->shortcode_base;
	}

	/**
	 * Maps shortcode to Visual Composer
	 */
	public function MapShortCodeVC() {
    
		if(function_exists('vc_map')) {
			$vc_map = array(
				'name'		=> esc_html__( 'Nav Tabs Holder', 'mascot-core' ),
				'base'		=>$this->shortcode_base,
				'category'	=> esc_html__( 'by TM', 'mascot-core' ),
				'icon'		=> 'mascot-vc-icons vc-icon-nav-tab',
				'as_parent' => array('only' => 'tm_nav_tabs_holder_item'),
				"js_view" => 'VcColumnView',
				'params'	=>array(
					array(
						'type'			=> 'textfield',
						"heading"		=> esc_html__( "Custom CSS class", 'mascot-core' ),
						"param_name"	=> "custom_css_class",
						"description"	=> esc_html__( 'To style particular content element.', 'mascot-core' ),
					),



					array(
						'type' => 'param_group',
						'heading' => esc_html__( 'Nav Tab Icons', 'js_composer' ),
						'param_name' => 'nav_tab_icons',
						'value' => rawurlencode( wp_json_encode( array(
							array(
								'title' => esc_html__( 'Title One', 'js_composer' ),
								'target_id' => 'navtab1',
								'icon' => '',
							),
							array(
								'title' => esc_html__( 'Title Two', 'js_composer' ),
								'target_id' => 'navtab2',
								'icon' => '',
							),
						) ) ),
						'params' => array(
								array(
									'type'			=> 'attach_image',
									"heading"		=> esc_html__( "Nav Tab Icon", 'mascot-core' ),
									"param_name"	=> "icon",
									"description"	=> esc_html__( 'Upload an icon.', 'mascot-core' ),
									'save_always'   => true,
									'admin_label'   => true,
								),
								array(
									'type'			=> 'textfield',
									"heading"		=> esc_html__( "Icon Title", 'mascot-core' ),
									"param_name"	=> "title",
									'admin_label'   => true,
								),
								array(
									'type'			=> 'textfield',
									"heading"		=> esc_html__( "Target Tab Content ID", 'mascot-core' ),
									"param_name"	=> "target_id",
									'admin_label'   => true,
								),

								array(
									'type'			=> 'checkbox',
									"heading"		=> esc_html__( "Make this Tab Active?", 'mascot-core' ),
									"param_name"	=> "active_tab",
									'std'			=> 'false',
								),
						),
						'callbacks' => array(
							'after_add' => 'vcChartParamAfterAddCallback',
						),
					),

					mascot_core_medinov_vc_add_css_editor(),

				)
			);
			vc_map( $vc_map );

			//Modify vc_map from themes
			if( function_exists('mascot_core_medinov_sc_nav_tabs_holder_vc_map_modifier') ) {
				mascot_core_medinov_sc_nav_tabs_holder_vc_map_modifier( $this->shortcode_base );
			}
		}
	}

	/**
	 * Renders shortcodes HTML
	 */
	public function render( $attr, $content = null ) {

		//Render Shortcode from themes
		if( function_exists('mascot_core_medinov_sc_nav_tabs_holder_render') && function_exists('vc_map') ) {
			return mascot_core_medinov_sc_nav_tabs_holder_render( $attr, $content );
		}
		
	}
}